From 6d5a297cccd337139a44d6b3bb457cf256ce4f08 Mon Sep 17 00:00:00 2001
From: Mitchell Amihod <mitchell.amihod@gmail.com>
Date: Fri, 18 May 2012 09:11:43 -0400
Subject: [PATCH] Add support for proper background images for toolbars. This
 means, no more glassy gradient - can apply a proper image
 tile, which will be streched to fit.

---
 TiUIWindowProxy.m |   11 +++++++++++
 TiUIiOSToolbar.m  |   11 +++++++++++
 2 files changed, 22 insertions(+), 0 deletions(-)

diff --git a/TiUIWindowProxy.m b/TiUIWindowProxy.m
index e9dfdca..19443bf 100644
--- a/TiUIWindowProxy.m
+++ b/TiUIWindowProxy.m
@@ -705,9 +705,20 @@
 			hasToolbar = (array != nil && [array count] > 0) ? YES : NO ;
 			BOOL translucent = [TiUtils boolValue:@"translucent" properties:properties def:NO];
 			BOOL animated = [TiUtils boolValue:@"animated" properties:properties def:hasToolbar];
+			id toolbarBackgroundImage = [properties valueForKey:@"backgroundImage"];
+			
 			[controller setToolbarItems:array animated:animated];
 			[ourNC setToolbarHidden:(hasToolbar == NO ? YES : NO) animated:animated];
 			[ourNC.toolbar setTranslucent:translucent];
+			
+			//toolbar which don't support setBackgroundImage (iOS < 5) will continue to have their default behaviour.
+			if(toolbarBackgroundImage && [ourNC.toolbar respondsToSelector:@selector(setBackgroundImage:forToolbarPosition:barMetrics:)]) {
+				UIImage * bgImage = [TiUtils image:toolbarBackgroundImage proxy:self];
+			    if (bgImage != nil) {
+					[ourNC.toolbar setBackgroundImage:bgImage forToolbarPosition:UIToolbarPositionAny barMetrics:UIBarMetricsDefault];
+			    }
+			}
+
 			[array release];
 			
 		}
diff --git a/TiUIiOSToolbar.m b/TiUIiOSToolbar.m
index b7dd739..086cc67 100644
--- a/TiUIiOSToolbar.m
+++ b/TiUIiOSToolbar.m
@@ -147,6 +147,17 @@
 	[toolBar setTranslucent:[TiUtils barTranslucencyForColor:newBarColor]];
 }
 
+-(void)setBackgroundImage_:(id)image
+{
+    UIImage* bgImage = [TiUtils loadBackgroundImage:image forProxy:self.proxy];
+
+	//toolbar which don't support setBackgroundImage (iOS < 5) will continue to have their default behaviour.
+    if (bgImage != nil && [toolBar respondsToSelector:@selector(setBackgroundImage:forToolbarPosition:barMetrics:)]) {
+		[toolBar setBackgroundImage:bgImage forToolbarPosition:UIToolbarPositionAny barMetrics:UIBarMetricsDefault];
+    }
+}
+
+
 -(void)setTranslucent_:(id)value
 {
 	[toolBar setTranslucent:[TiUtils boolValue:value]];
-- 
1.7.8.3

